@@ -43,11 +43,11 @@ import (
 	"go.opentelemetry.io/otel/trace"
 	"google.golang.org/api/option"
 
-	"github.com/GoogleContainerTools/skaffold/fs"
-	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/constants"
-	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/output/log"
-	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/user"
-	"github.com/GoogleContainerTools/skaffold/proto/v1"
+	"github.com/GoogleContainerTools/skaffold/v2/fs"
+	"github.com/GoogleContainerTools/skaffold/v2/pkg/skaffold/constants"
+	"github.com/GoogleContainerTools/skaffold/v2/pkg/skaffold/output/log"
+	"github.com/GoogleContainerTools/skaffold/v2/pkg/skaffold/user"
+	"github.com/GoogleContainerTools/skaffold/v2/proto/v1"
 )
 
 func ExportMetrics(exitCode int) error {
@@ -183,10 +183,10 @@ func createMetrics(ctx context.Context, meter skaffoldMeter) {
 	}
 	labels = append(labels, sharedLabels...)
 	platformLabel := attribute.String("host_os_arch", fmt.Sprintf("%s/%s", meter.OS, meter.Arch))
-	runCounter := metric.Must(m).NewInt64ValueRecorder("launches", metric.WithDescription("Skaffold Invocations"))
+	runCounter := NewInt64ValueRecorder(m, "launches", metric.WithDescription("Skaffold Invocations"))
 	runCounter.Record(ctx, 1, labels...)
 
-	durationRecorder := metric.Must(m).NewFloat64ValueRecorder("launch/duration",
+	durationRecorder := NewFloat64ValueRecorder(m, "launch/duration",
 		metric.WithDescription("durations of skaffold commands in seconds"))
 	durationRecorder.Record(ctx, meter.Duration.Seconds(), labels...)
 	if meter.Command != "" {
@@ -210,7 +210,7 @@ func createMetrics(ctx context.Context, meter skaffoldMeter) {
 }
 
 func flagMetrics(ctx context.Context, meter skaffoldMeter, m metric.Meter, randLabel attribute.KeyValue) {
-	flagCounter := metric.Must(m).NewInt64ValueRecorder("flags", metric.WithDescription("Tracks usage of enum flags"))
+	flagCounter := NewInt64ValueRecorder(m, "flags", metric.WithDescription("Tracks usage of enum flags"))
 	for k, v := range meter.EnumFlags {
 		labels := []attribute.KeyValue{
 			attribute.String("flag_name", k),
@@ -224,13 +224,13 @@ func flagMetrics(ctx context.Context, meter skaffoldMeter, m metric.Meter, randL
 }
 
 func commandMetrics(ctx context.Context, meter skaffoldMeter, m metric.Meter, labels ...attribute.KeyValue) {
-	commandCounter := metric.Must(m).NewInt64ValueRecorder(meter.Command,
+	commandCounter := NewInt64ValueRecorder(m, meter.Command,
 		metric.WithDescription(fmt.Sprintf("Number of times %s is used", meter.Command)))
 	labels = append(labels, attribute.String("error", meter.ErrorCode.String()))
 	commandCounter.Record(ctx, 1, labels...)
 
 	if meter.Command == "dev" || meter.Command == "debug" {
-		iterationCounter := metric.Must(m).NewInt64ValueRecorder(fmt.Sprintf("%s/iterations", meter.Command),
+		iterationCounter := NewInt64ValueRecorder(m, fmt.Sprintf("%s/iterations", meter.Command),
 			metric.WithDescription(fmt.Sprintf("Number of iterations in a %s session", meter.Command)))
 
 		counts := make(map[string]map[proto.StatusCode]int)
@@ -255,19 +255,19 @@ func commandMetrics(ctx context.Context, meter skaffoldMeter, m metric.Meter, la
 }
 
 func deployerMetrics(ctx context.Context, meter skaffoldMeter, m metric.Meter, labels ...attribute.KeyValue) {
-	deployerCounter := metric.Must(m).NewInt64ValueRecorder("deployer", metric.WithDescription("Deployers used"))
+	deployerCounter := NewInt64ValueRecorder(m, "deployer", metric.WithDescription("Deployers used"))
 	for _, deployer := range meter.Deployers {
 		deployerCounter.Record(ctx, 1, append(labels, attribute.String("deployer", deployer))...)
 	}
 	if meter.HelmReleasesCount > 0 {
-		multiReleasesCounter := metric.Must(m).NewInt64ValueRecorder("helmReleases", metric.WithDescription("Multiple helm releases used"))
+		multiReleasesCounter := NewInt64ValueRecorder(m, "helmReleases", metric.WithDescription("Multiple helm releases used"))
 		multiReleasesCounter.Record(ctx, 1, append(labels, attribute.Int("count", meter.HelmReleasesCount))...)
 	}
 }
 
 func resourceSelectorMetrics(ctx context.Context, meter skaffoldMeter, m metric.Meter, labels ...attribute.KeyValue) {
 	if len(meter.ResourceFilters) > 0 {
-		resourceFilters := metric.Must(m).NewInt64ValueRecorder("resource-filters", metric.WithDescription("The resource filters defined for rendering and/or deployment"))
+		resourceFilters := NewInt64ValueRecorder(m, "resource-filters", metric.WithDescription("The resource filters defined for rendering and/or deployment"))
 		for _, resourceFilter := range meter.ResourceFilters {
 			resourceFilters.Record(ctx, 1, append(labels, attribute.String("source", resourceFilter.Source), attribute.String("type", resourceFilter.Type))...)
 		}
@@ -275,10 +275,10 @@ func resourceSelectorMetrics(ctx context.Context, meter skaffoldMeter, m metric.
 }
 
 func builderMetrics(ctx context.Context, meter skaffoldMeter, m metric.Meter, platformLabel attribute.KeyValue, labels ...attribute.KeyValue) {
-	builderCounter := metric.Must(m).NewInt64ValueRecorder("builders", metric.WithDescription("Builders used"))
-	artifactCounter := metric.Must(m).NewInt64ValueRecorder("artifacts", metric.WithDescription("Number of artifacts used"))
-	dependenciesCounter := metric.Must(m).NewInt64ValueRecorder("artifact-dependencies", metric.WithDescription("Number of artifacts with dependencies"))
-	platformsCounter := metric.Must(m).NewInt64ValueRecorder("artifact-with-platforms", metric.WithDescription("Number of artifacts with target platforms specified"))
+	builderCounter := NewInt64ValueRecorder(m, "builders", metric.WithDescription("Builders used"))
+	artifactCounter := NewInt64ValueRecorder(m, "artifacts", metric.WithDescription("Number of artifacts used"))
+	dependenciesCounter := NewInt64ValueRecorder(m, "artifact-dependencies", metric.WithDescription("Number of artifacts with dependencies"))
+	platformsCounter := NewInt64ValueRecorder(m, "artifact-with-platforms", metric.WithDescription("Number of artifacts with target platforms specified"))
 	for builder, count := range meter.Builders {
 		bLabel := attribute.String("builder", builder)
 		builderCounter.Record(ctx, 1, append(labels, bLabel)...)
@@ -288,25 +288,25 @@ func builderMetrics(ctx context.Context, meter skaffoldMeter, m metric.Meter, pl
 	}
 
 	if len(meter.ResolvedBuildTargetPlatforms) > 0 {
-		platforms := metric.Must(m).NewInt64ValueRecorder("build-platforms", metric.WithDescription("The resolved build target platforms for each run"))
+		platforms := NewInt64ValueRecorder(m, "build-platforms", metric.WithDescription("The resolved build target platforms for each run"))
 		for _, buildPlatform := range meter.ResolvedBuildTargetPlatforms {
 			platforms.Record(ctx, 1, append(labels, platformLabel, attribute.String("os_arch", buildPlatform))...)
 		}
 	}
 
 	if len(meter.CliBuildTargetPlatforms) > 0 {
-		platforms := metric.Must(m).NewInt64ValueRecorder("cli-platforms", metric.WithDescription("The build target platforms specified via CLI flag --platform"))
+		platforms := NewInt64ValueRecorder(m, "cli-platforms", metric.WithDescription("The build target platforms specified via CLI flag --platform"))
 		platforms.Record(ctx, 1, append(labels, platformLabel, attribute.String("os_arch", meter.CliBuildTargetPlatforms))...)
 	}
 
 	if len(meter.DeployNodePlatforms) > 0 {
-		platforms := metric.Must(m).NewInt64ValueRecorder("node-platforms", metric.WithDescription("The kubernetes cluster node platforms"))
+		platforms := NewInt64ValueRecorder(m, "node-platforms", metric.WithDescription("The kubernetes cluster node platforms"))
 		platforms.Record(ctx, 1, append(labels, platformLabel, attribute.String("os_arch", meter.DeployNodePlatforms))...)
 	}
 }
 
 func hooksMetrics(ctx context.Context, meter skaffoldMeter, m metric.Meter, labels ...attribute.KeyValue) {
-	hooksCounter := metric.Must(m).NewInt64ValueRecorder("hooks", metric.WithDescription("Lifecycle hooks configured"))
+	hooksCounter := NewInt64ValueRecorder(m, "hooks", metric.WithDescription("Lifecycle hooks configured"))
 
 	for hook, count := range meter.Hooks {
 		hLabel := attribute.String("hookPhase", string(hook))
@@ -315,23 +315,23 @@ func hooksMetrics(ctx context.Context, meter skaffoldMeter, m metric.Meter, labe
 }
 
 func errorMetrics(ctx context.Context, meter skaffoldMeter, m metric.Meter, labels ...attribute.KeyValue) {
-	errCounter := metric.Must(m).NewInt64ValueRecorder("errors", metric.WithDescription("Skaffold errors"))
+	errCounter := NewInt64ValueRecorder(m, "errors", metric.WithDescription("Skaffold errors"))
 	errCounter.Record(ctx, 1, append(labels, attribute.String("error", meter.ErrorCode.String()))...)
 
 	labels = append(labels, attribute.String("command", meter.Command))
 
 	switch meter.ErrorCode {
 	case proto.StatusCode_UNKNOWN_ERROR:
-		unknownErrCounter := metric.Must(m).NewInt64ValueRecorder("errors/unknown", metric.WithDescription("Unknown Skaffold Errors"))
+		unknownErrCounter := NewInt64ValueRecorder(m, "errors/unknown", metric.WithDescription("Unknown Skaffold Errors"))
 		unknownErrCounter.Record(ctx, 1, labels...)
 	case proto.StatusCode_TEST_UNKNOWN:
-		unknownCounter := metric.Must(m).NewInt64ValueRecorder("test/unknown", metric.WithDescription("Unknown test Skaffold Errors"))
+		unknownCounter := NewInt64ValueRecorder(m, "test/unknown", metric.WithDescription("Unknown test Skaffold Errors"))
 		unknownCounter.Record(ctx, 1, labels...)
 	case proto.StatusCode_DEPLOY_UNKNOWN:
-		unknownCounter := metric.Must(m).NewInt64ValueRecorder("deploy/unknown", metric.WithDescription("Unknown deploy Skaffold Errors"))
+		unknownCounter := NewInt64ValueRecorder(m, "deploy/unknown", metric.WithDescription("Unknown deploy Skaffold Errors"))
 		unknownCounter.Record(ctx, 1, labels...)
 	case proto.StatusCode_BUILD_UNKNOWN:
-		unknownCounter := metric.Must(m).NewInt64ValueRecorder("build/unknown", metric.WithDescription("Unknown build Skaffold Errors"))
+		unknownCounter := NewInt64ValueRecorder(m, "build/unknown", metric.WithDescription("Unknown build Skaffold Errors"))
 		unknownCounter.Record(ctx, 1, labels...)
 	}
 }
