@@ -19,7 +19,7 @@ package resource
 import (
 	"fmt"
 
-	"github.com/GoogleContainerTools/skaffold/proto/v1"
+	"github.com/GoogleContainerTools/skaffold/v2/proto/v1"
 )
 
 type Status struct {
